# Plone ONLYOFFICE integration plugin

Moved to [onlyoffice.plone](https://pypi.org/project/onlyoffice.plone/)

**Please note:** you have the previous plugin version installed (earlier plugin versions with the previous name onlyoffice.connector), please remove it before installing the new version.
